<?php

namespace Drupal\social_post_facebook\Plugin\Network;

use Drupal\social_post\Plugin\Network\NetworkInterface;

/**
 * Defines an interface for Facebook Post Network Plugin.
 */
interface FacebookPostInterface extends NetworkInterface {

  /**
   * Gets the absolute url of the callback.
   *
   * @return string
   *   The callback url.
   */
  public function getOauthCallback();

  /**
   * Wrapper for post method.
   *
   * @param string $access_token
   *   The access token.
   * @param string $status
   *   The tweet text.
   */
  public function doPost($access_token, $status);

  /**
   * Gets a Facebook instance with oauth_token and oauth_token_secret.
   *
   * This method creates the SDK object by also passing the oauth_token and
   * oauth_token_secret. It is used for getting permanent tokens from
   * Facebook and authenticating users that has already granted permission.
   *
   * @return \Facebook\Facebook
   *   The instance of the connection to Facebook.
   */
  public function getSdk2();

  /**
   * Return a list of the required permissions requested by the app.
   *
   * @return array
   *   A list of permissions.
   */
  public function getPermissions();

}
